Contributing
============

Any contribution is **highly** appreciated, no matter whether it is a small bug fix, feature implementation or typo in the docs.

You can contribute in many ways:

* report bugs;
* fix bugs;
* implement features;
* write documentation;
* simply tell us what you love about remodel or what you'd like to see in it!


## Getting Started!

**Fork** this repo, `pip install -e .` the project, do your magic, `tox` and submit a pull request on the **develop** branch!

> Issues, features, bugs and questions are tracked at https://github.com/linkyndy/remodel/issues

> Documentation is found at https://github.com/linkyndy/remodel/wiki
